package com.zh.test_zabbix.model.zabbixModel.host;

import lombok.Data;

@Data
public class HostInterface {

    /*	(只读) 主机接口的可用性。
        可能的值有:
        0 - (默认) 未知;
        1 - 可用;
        2 - 不可用。 */
    Integer available = 0;

    /* 接口的附加对象。 如果接口 'type'是SNMP，则必选 */
    InterfaceSNMPDetail details;

    /* 	(只读) 不可用主机接口的下一次轮询时间。 */
    String disable_until;

    /* 	(必选)接口使用的DNS名称
    如果通过IP直接连接，则可以为空。 */
    String dns;

    /* (只读) 主机接口不可用的错误文本。 */
    String error;

    /* 	(只读) 主机接口不可用开始时间。 */
    String errors_from;

    /* 	(必选)接口所属的主机ID。 */
    String hostid;

    /* 	(只读) 接口的ID。 */
    String interfaceid;

    /* (必选)接口使用的IP地址。
    如果使用DNS域名连接，可以设置为空。 */
    String ip;

    /* (必选)该接口是否在主机上用作默认的接口，在主机上只能将某种类型的一个接口设置为默认值。
    可能的值有:
    0 - 不是默认;
    1 - 默认。 */
    Integer main;

    /* 	接口使用的端口号，可以包含用户宏。 */
    String port;

    /* (必选)接口类型。
    可能的值有:
    1 - agent;
    2 - SNMP;
    3 - IPMI;
    4 - JMX。 */
    Integer type;

    /* (必选)是否通过IP进行连接。
    可能的值有:
    0 - 使用主机DNS进行连接;
    1 - 使用主机接口的主机IP进行连接。 */
    Integer useip;

}

@Data
class InterfaceSNMPDetail {

    /* (必选)SNMP接口版本。
    可能的值有:
    1 - SNMPv1;
    2 - SNMPv2c;
    3 - SNMPv3 */
    Integer version;

    /* 是否使用批量的SNMP请求.
    可能的值有:
    0 - 不使用批量请求;
    1 - (默认) - 使用批量请求。 */
    Integer bulk = 1;

    /* (必选)SNMP 团体字。 仅在SNMPv1和SNMPv2接口中使用。 */
    String community;

    /* 	SNMPv3 安全名称。仅在SNMPv3接口中使用。 */
    String securityname;

    /* SNMPv3安全级别。 仅在SNMPv3接口中使用。
    可能的值有:
    0 - (默认) - noAuthNoPriv;
    1 - authNoPriv;
    2 - authPriv. */
    String securitylevel = "0";

    /* SNMPv3身份验证密码。仅在SNMPv3接口中使用。 */
    String authpassphrase;

    /* SNMPv3隐私密码。仅在SNMPv3接口中使用。 */
    String privpassphrase;

    /* 	SNMPv3身份认证协议。仅在SNMPv3接口中使用。
    可能的值有:
    0 - (默认) - MD5;
    1 - SHA1;
    2 - SHA224;
    3 - SHA256;
    4 - SHA384;
    5 - SHA512. */
    Integer authprotocol = 0;

        /* 	SNMPv3隐私协议。仅在SNMPv3接口中使用。
        可能的值有:
        0 - (默认) - DES;
        1 - AES128;
        2 - AES192;
        3 - AES256;
        4 - AES192C;
        5 - AES256C. */

    Integer privprotocol = 0;

    /* 	SNMPv3上下文名称。仅在SNMPv3接口中使用。 */
    String contextname;

}
