package com.zh.test_zabbix.model.zabbixModel.item;

import lombok.Data;

@Data
public class ApiItem {

    /* （只读） 监控项 ID。 */
    String itemid;

    /* （必填）更新监控项的时间间隔。接收秒或者带后缀的时间单位（30s、1m、2h、1d）。
    可以通过 自定义间隔 进行组合，从而更灵活的设置间隔时间。
    多个间隔使用分号分隔。
    可以使用用户宏。单个宏必须填充完整个字段。不支持字段中包含多个宏或文本混合宏。
    通过编写由正斜杠分隔的两段宏能更加灵活地设置间隔时间 (e.g. {$FLEX_INTERVAL}/{$FLEX_PERIOD}).

    Zabbix采集器，相关项监控和Zabbix agent（主动）可选 mqtt.get key。 */
    String delay;

    /* （必填）监控项所属的主机或模板的 ID。
    更新操作中，此字段为只读。 */
    String hostid;

    /* 	监控项主机接口的 ID。
    仅用于主机监控项。对于Zabbix agent（主动），内部检查、采集器、可计算的监控项、相关项监控、数据库监控和脚本监控项是不需要的。 */
    String interfaceid;

    /* （必填）监控项关键字。 */
    String key_;

    /* （必填）监控项名称。 */
    String name;

    /* （必要项）监控项类型。
    可用值：
        0 - Zabbix agent；
        2 - zabbix 采集器；
        3 - 简单检查；
        5 - 内部检查；
        7 - Zabbix agent (主动)；
        9 - web 监控项；
        10 - 外部检查；
        11 - 数据库监控；
        12 - IPMI agent；
        13 - SSH agent；
        14 - Telnet agent；
        15 - 可计算的监控；
        16 - JMX agent；
        17 - SNMP trap；
        18 - 相关项监控；
        19 - HTTP agent；
        20 - SNMP agent；
        21 - 脚本。 */
    int type;

    /* （必填）URL 字符串，用于 HTTP agent 监控项类型。
    支持用户宏 {HOST.IP}、{HOST.CONN}、{HOST.DNS}、{HOST.HOST}、{HOST.NAME}、{ITEM.ID}、{ITEM.KEY}。 */
    String url;

    /* （必填）监控项数据类型
    可用值：0 - 浮点型；1 - 字符；2 - 日志；3 - 无符号数字；4 - 文本。 */
    String value_type;

    /* HTTP agent 监控项字段。也允许在采集器监控项中填充值。
    0 - （默认） 不允许接受传入数据。
    1 - 允许接受传入数据。 */
    int allow_traps = 0;

    /* 	仅 SSH agent 监控项或 HTTP agent 监控项使用。
    SSH agent 身份验证方法可用值：
    0 - （默认） 密码；
    1 - 公钥。

    HTTP agent 身份验证方法可用值：
    0 - （默认） 无认证；
    1 - basic 认证；
    2 - NTLM 认证
    3 - Kerberos 认证； */
    int authtype = 0;

    /* 监控项说明。 */
    String description;

    /* 	（只读） 如果更新监控项时报错，则显示错误信息。 */
    String error;

    /* （只读） 监控项来源
    可用值：
    0 - 平台监控项；
    4 - 发现监控项。 */
    int flags;

    /* HTTP agent 监控项字段。在合并数据时遵循响应重定向。
    0 - 不遵循重定向；
    1 - （默认） 遵循重定向。 */
    int follow_redirects = 1;

    /* 	HTTP agent 监控项字段。具有 HTTP（S）请求头的对象，其中请求头名用作键，请求头值用作值。
    示例：{ "User-Agent": "Zabbix" } */
    String headers;

    /* 历史数据应保留多长时间的单位。同样接受用户宏。
    默认： 90天。 */
    String history;

    /* 	HTTP agent 监控项字段。HTTP（S）agent 连接字符串。 */
    String http_proxy;

    /* 由监控项填充的主机资产字段的 ID。
    请参阅 主机资产清单页 ，了解更多受支持的主机资产清单字段及其 ID 列表。
    默认： 0 */
    int inventory_link = 0;

    /* 	IPMI 传感器。仅用于 IPMI 监控项。 */
    String ipmi_sensor;

    /* JMX agent 自定义连接字符串。
    默认值：service:jmx:rmi:///jndi/rmi://{HOST.CONN}:{HOST.PORT}/jmxrmi     */
    String jmx_endpoint;

    /* 只读） 上一次更新监控项的时间。
    默认情况下，仅显示过去24小时内的值。您可以通过更改 管理 → 通用 菜单中的 最大历史显示周期 参数值来延长此时间段。 */
    String lastclock;

    /* （只读） 上一次更新监控项时的纳秒数。
    默认情况下，仅显示过去24小时内的值。您可以通过更改 管理 → 通用 菜单中的 最大历史显示周期 参数值来延长此时间段。 */
    int lastns;

    /* （只读） 监控项最后获取的值。
    默认情况下，仅显示过去24小时内的值。您可以通过更改 管理 → 通用 菜单中的 最大历史显示周期 参数值来延长此时间段。 */
    String lastvalue;

    /* 日志条目中的时间格式。仅日志监控项使用。 */
    String logtimefmt;

    /* 	主监控项 ID。
    最多允许递归 3 个相关项监控，且相关监控项的最大计数为 29999。
    相关监控项的先决条件。 */
    int master_itemid;

    /* HTTP agent 监控项字段。将响应转换为 JSON 格式。
    0 - （默认） 原格式；
    1 - 转换为 JSON 格式。 */
    int output_format = 0;

    /* 其他参数取决于监控项的类型：
    - SSH 和 Telnet agent 的可执行脚本；
    - 数据库监控项的 SQL 查询；
    - 可计算监控项的公式；
    - 脚本监控项的脚本。 */
    String params;

    /* 脚本监控项的其他参数。具有 “名称” 和 “值” 属性的对象数组，其中名称必须唯一。 */
    String parameters;

    /* 验证密码。用于一般检查、SSH、Telnet、数据库监控、JMX 和 HTTP agent 监控项。
    当 JMX 使用时，用户名应与密码一起指定，或者两个属性都留空。 */
    String password;

    /* HTTP agent 监控项字段。Posts 属性中存储的 post 数据体的类型。
    0 - （默认） 原始数据；
    2 - JSON 数据；
    3 - XML 数据。 */
    int post_type = 0;

    /* HTTP agent 监控项字段。HTTP（S）请求正文数据。与 post_type 一同使用。 */
    String posts;

    /* 	（只读） 监控项的上一个值。
    默认情况下，仅显示过去24小时内的值。您可以通过更改 管理 → 通用 菜单中的 最大历史显示周期 参数值来延长此时间段。 */
    String prevvalue;

    /* 私钥文件的名称。 */
    String privatekey;

    /* 公钥文件的名称。 */
    String publickey;

    /* HTTP agent 监控项字段。查询参数。具有 “键”：“值” 对的对象数组，其中值可以是空字符串。 */
    String query_fields;

    /* 	HTTP agent 监控项字段。请求方法类型：
    0 - （默认） GET；
    1 - POST；
    2 - PUT；
    3 - HEAD */
    int request_method = 0;

    /* 	HTTP agent 监控项字段。具体存储响应的部分。
    0 - （默认） Body；
    1 - Headers；
    2 - Body and headers。
    对于 request_method HEAD 仅允许方法 1。 */
    int retrieve_mode = 0;

    /* SNMP OID。 */
    String snmp_oid;

    /* HTTP agent 监控项字段。SSL 公钥文件路径。 */
    String ssl_cert_file;

    /* HTTP agent 监控项字段。SSL 私钥文件路径。 */
    String ssl_key_file;

    /* HTTP agent 监控项字段。SSL 密钥文件的密码。 */
    String ssl_key_password;

    /* （只读） 监控项状态。
    可用值：
    0 - （默认） 标准；
    1 - 不受支持。 */
    int state = 0;

    /* 监控项状态。
    可用值：
    0 - （默认） 启用监控项；
    1 - 禁用监控项。 */
    int status = 0;

    /* HTTP agent 监控项字段。目标HTTP状态代码的范围，用逗号分隔。还支持将用户宏作为逗号分隔列表的一部分。
    示例： 200,200-{$M},{$M},200-400 */
    String status_codes;

    /* 	（只读） 父模板监控项的 ID。
    提示：使用 hostid 属性指定监控项所属的模板。 */
    String templateid;

    /* 	监控项数据轮询请求超时。用于 HTTP agent 和脚本监控项。支持用户宏。
    默认：3秒。
    最大值：60秒。 */
    String timeout;

    /* 	允许的主机。采集器监控项或 HTTP agent 监控项使用。 */
    String trapper_hosts;

    /* 趋势数据应保留多长时间的单位。可接受用户宏。
    默认：365天。 */
    String trends;

    /* 值的单位。 */
    String units;

    /* 用于身份验证的用户名。用于一般检查、SSH、Telnet、数据库监控项、JMX 和 HTTP agent 监控项。
    SSH 和 Telnet 监控项先决条件。
    当 JMX 使用时，用户名应与密码一起指定，或者两个属性都留空。 */
    String username;

    /* 通用唯一标识符，用于将导入的监控项链接到现有监控项。仅模板包含项目使用。如果未指定会自动生成。
    对于更新操作，此字段为 只读。 */
    String uuid;

    /* 关联值映射 ID。 */
    String valuemapid;

    /* HTTP agent 监控项字段。验证 URL 中的主机名是否位于主机证书的公用名字段或使用者备用名字段中。
    0 - （默认） 不验证；
    1 - 验证。 */
    int verify_host = 0;

    /* 	HTTP agent 监控项字段。验证主机证书的真实性。
    0 - （默认） 不验证；
    1 - 验证。 */
    int verify_peer = 0;

}


